@@ -9,7 +9,7 @@ Using the calculators hypothesis tests can then be performed.
 """
 from .mle import fixed_poi_fit
 from .. import get_backend
-from .test_statistics import qmu
+from .test_statistics import qmu, qmu_tilde
 
 
 def generate_asimov_data(asimov_mu, data, pdf, init_pars, par_bounds):
@@ -59,6 +59,20 @@ class AsymptoticTestStatDistribution(object):
         self.shift = shift
         self.sqrtqmuA_v = None
 
+    def cdf(self, value):
+        """
+        Compute the value of the cumulative distribution function for a given value of the test statistic.
+
+        Args:
+            value (`float`): The test statistic value.
+
+        Returns:
+            Float: The integrated probability to observe a test statistic less than or equal to the observed ``value``.
+
+        """
+        tensorlib, _ = get_backend()
+        return tensorlib.normal_cdf((value - self.shift))
+
     def pvalue(self, value):
         """
         Compute the :math:`p`-value for a given value of the test statistic.
@@ -141,14 +155,21 @@ class AsymptoticCalculator(object):
 
         """
         tensorlib, _ = get_backend()
-        qmu_v = qmu(poi_test, self.data, self.pdf, self.init_pars, self.par_bounds)
+
+        teststat_func = qmu_tilde if self.qtilde else qmu
+
+        qmu_v = teststat_func(
+            poi_test, self.data, self.pdf, self.init_pars, self.par_bounds
+        )
         sqrtqmu_v = tensorlib.sqrt(qmu_v)
 
         asimov_mu = 0.0
         asimov_data = generate_asimov_data(
             asimov_mu, self.data, self.pdf, self.init_pars, self.par_bounds
         )
-        qmuA_v = qmu(poi_test, asimov_data, self.pdf, self.init_pars, self.par_bounds)
+        qmuA_v = teststat_func(
+            poi_test, asimov_data, self.pdf, self.init_pars, self.par_bounds
+        )
         self.sqrtqmuA_v = tensorlib.sqrt(qmuA_v)
 
         if not self.qtilde:  # qmu
